==> groupfolders-v19.1.5.tar.gz: groupfolders/l10n/sv.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Du kan inte ta bort din egen läsbehörighet.",
    "Team folders" : "Teammappar",
    "Admin configured folders shared with everyone in a team" : "Admin-konfigurerade mappar som delas av alla i ett team",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Administratörskonfigurerade mappar delas med alla i ett team.\n\nMappar kan konfigureras från \"Teammappar\" i admininställningarna.\n\nNär en mapp har skapats kan administratören ge åtkomst till en eller flera team, kontrollera deras skriv-/delningsbehörigheter och tilldela en kvot för mappen.\nFrån och med Hub 10/Nextcloud 31 måste administratören vara en del av teamet för att kunna tilldela det en Teammapp.",
    "Unset" : "Inaktivera",
    "Denied (Inherited permission)" : "Nekad (ärvd rättighet)",
    "Allowed (Inherited permission)" : "Tillåten (ärvd rättighet)",
    "Denied" : "Nekad",
    "Allowed" : "Tillåten",
    "Access denied" : "Åtkomst nekades",
    "Access allowed" : "Åtkomst tillåten",
    "Inherit permission" : "Ärv rättighet",
    "Deny" : "Neka",
    "Allow" : "Tillåt",
    "Group" : "Grupp",
    "Team" : "Team",
    "Team folder" : "Teammapp",
    "Read" : "Läsa",
    "Write" : "Skriva",
    "Create" : "Skapa",
    "Delete" : "Ta bort",
    "Share" : "Dela",
    "You" : "Du",
    "Remove access rule" : "Ta bort accessregel",
    "Add advanced permission rule" : "Lägg till avancerad accessregel",
    "Select a user or group" : "Välj en användare eller grupp",
    "Open Team folder" : "Öppna teammapp",
    "Permission denied. User does not have sufficient permissions." : "Åtkomst nekad. Användaren har inte tillräckliga behörigheter.",
    "Unexpected status from server" : "Oväntad status från servern",
    "List of Team folders." : "Lista över teammappar.",
    "No Team folders yet" : "Inga teammappar än",
    "Team folders will show up here" : "Teammappar kommer att visas här",
    "Add group" : "Lägg till grupp",
    "Default" : "Förvald",
    "Unlimited" : "Obegränsat",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Är du säker på att du vill radera \"{folderName}\" och alla dess filer? Denna operation kan inte ångras",
    "Delete \"{folderName}\"?" : "Ta bort \"{folderName}\"?",
    "Team folder admin delegation" : "Administratörsdelegering för teammapp",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud tillåter att du delegerar administrationen av teammappar till användare som inte är administratörer.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Ange nedan vilka grupper som tillåts hantera teammappar och använda dess API/REST.",
    "They will have access to all Team folders." : "De kommer att ha tillgång till alla teammappar.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Ange nedan vilka grupper som får hantera teammappar och endast använda dess API/REST.",
    "They will only have access to Team folders for which they have advanced permissions." : "De kommer bara att ha tillgång till teammappar som de har avancerade behörigheter för.",
    "Group or team" : "Grupp eller team",
    "Sort by number of groups or teams that have access to this folder" : "Sortera efter antal grupper eller team som har åtkomst till den här mappen",
    "Sort by number of groups that have access to this folder" : "Sortera efter antal grupper som har åtkomst till den här mappen",
    "Folder name" : "Mappnamn",
    "Quota" : "Utrymme",
    "Advanced Permissions" : "Avancerade behörigheter",
    "Pagination of team folders" : "Sidindelning av teammappar",
    "Previous" : "Föregående",
    "Next" : "Nästa",
    "User" : "Användare",
    "Unknown" : "Okänd",
    "Users/groups that can manage" : "Användare/grupper som kan hantera",
    "None" : "Ingen",
    "No other groups or teams available" : "Inga andra grupper eller team tillgängliga",
    "No other groups available" : "Inga andra grupper tillgängliga",
    "{displayName} (team)" : "{displayName} (team)",
    "Add group or team" : "Lägg till grupp eller team",
    "{size} used" : "{size} använt",
    "Other …" : "Övrigt ...",
    "You can not remove your own read permission." : "Du kan inte ta bort din egen läsbehörighet.",
    "Group folders" : "Gruppmappar",
    "Admin configured folders shared with everyone in a group" : "Admin-konfigurerade mappar som delas av alla i en grupp",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Admin-konfigurerade mappar som delas med alla i en grupp.\n\nMappar kan konfigureras från *Gruppmappar* i admininställningarna.\n\nNär en mapp har skapats kan administratören ge åtkomst till mappen till en eller flera grupper, kontrollera deras skriv/delnings-behörigheter och tilldela en kvot för mappen.",
    "Group folder" : "Gruppmapp",
    "Open group folder" : "Öppna gruppmapp",
    "List of group folders." : "Lista över gruppmappar.",
    "No group folders yet" : "Inga gruppmappar än",
    "Group folders will show up here" : "Gruppmappar kommer att visas här",
    "Group folder admin delegation" : "Administratörsdelegering för gruppmapp",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud tillåter att du delegerar administrationen av gruppmappar till användare som inte är administratörer.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Ange nedan vilka grupper som tillåts hantera gruppmappar och använda dess API/REST.",
    "They will have access to all group folders." : "De kommer att ha tillgång till alla gruppmappar.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Ange nedan vilka grupper som får hantera gruppmappar och endast använda dess API/REST.",
    "They will only have access to group folders for which they have advanced permissions." : "De kommer bara att ha tillgång till gruppmappar som de har avancerade behörigheter för.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Admin-konfigurerade mappar som delas med alla i ett team.\n\nMappar kan konfigureras från *Teammappar* i admininställningarna.\n\nNär en mapp har skapats kan administratören ge åtkomst till mappen till ett eller flera team, kontrollera deras skriv/delnings-behörigheter och tilldela en kvot för mappen."
},
"nplurals=2; plural=(n != 1);");

==> groupfolders-v20.1.1.tar.gz: groupfolders/l10n/sv.js <==
OC.L10N.register(
    "groupfolders",
    {
    "You cannot remove your own read permission." : "Du kan inte ta bort din egen läsbehörighet.",
    "Team folders" : "Teammappar",
    "Unset" : "Inaktivera",
    "Denied (Inherited permission)" : "Nekad (ärvd rättighet)",
    "Allowed (Inherited permission)" : "Tillåten (ärvd rättighet)",
    "Denied" : "Nekad",
    "Allowed" : "Tillåten",
    "Access denied" : "Åtkomst nekades",
    "Access allowed" : "Åtkomst tillåten",
    "Inherit permission" : "Ärv rättighet",
    "Deny" : "Neka",
    "Allow" : "Tillåt",
    "Group" : "Grupp",
    "Team" : "Team",
    "Team folder" : "Teammapp",
    "Read" : "Läsa",
    "Write" : "Skriva",
    "Create" : "Skapa",
    "Delete" : "Ta bort",
    "Share" : "Dela",
    "You" : "Du",
    "Remove access rule" : "Ta bort accessregel",
    "Add advanced permission rule" : "Lägg till avancerad accessregel",
    "Select a user or group" : "Välj en användare eller grupp",
    "Open Team folder" : "Öppna teammapp",
    "Permission denied. User does not have sufficient permissions." : "Åtkomst nekad. Användaren har inte tillräckliga behörigheter.",
    "Unexpected status from server" : "Oväntad status från servern",
    "List of Team folders." : "Lista över teammappar.",
    "No Team folders yet" : "Inga teammappar än",
    "Team folders will show up here" : "Teammappar kommer att visas här",
    "Add group" : "Lägg till grupp",
    "Default" : "Förvald",
    "Unlimited" : "Obegränsat",
    "Are you sure you want to delete \"{folderName}\" and all files inside? This operation cannot be undone" : "Är du säker på att du vill radera \"{folderName}\" och alla dess filer? Denna operation kan inte ångras",
    "Delete \"{folderName}\"?" : "Ta bort \"{folderName}\"?",
    "Team folder admin delegation" : "Administratörsdelegering för teammapp",
    "Nextcloud allows you to delegate the administration of Team folders to non-admin users." : "Nextcloud tillåter att du delegerar administrationen av teammappar till användare som inte är administratörer.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST." : "Ange nedan vilka grupper som tillåts hantera teammappar och använda dess API/REST.",
    "They will have access to all Team folders." : "De kommer att ha tillgång till alla teammappar.",
    "Specify below the groups that will be allowed to manage Team folders and use its API/REST only." : "Ange nedan vilka grupper som får hantera teammappar och endast använda dess API/REST.",
    "They will only have access to Team folders for which they have advanced permissions." : "De kommer bara att ha tillgång till teammappar som de har avancerade behörigheter för.",
    "Group or team" : "Grupp eller team",
    "Sort by number of groups or teams that have access to this folder" : "Sortera efter antal grupper eller team som har åtkomst till den här mappen",
    "Sort by number of groups that have access to this folder" : "Sortera efter antal grupper som har åtkomst till den här mappen",
    "Folder name" : "Mappnamn",
    "Quota" : "Utrymme",
    "Advanced Permissions" : "Avancerade behörigheter",
    "Pagination of team folders" : "Sidindelning av teammappar",
    "Previous" : "Föregående",
    "Next" : "Nästa",
    "User" : "Användare",
    "Unknown" : "Okänd",
    "Users/groups that can manage" : "Användare/grupper som kan hantera",
    "None" : "Ingen",
    "No other groups or teams available" : "Inga andra grupper eller team tillgängliga",
    "No other groups available" : "Inga andra grupper tillgängliga",
    "{displayName} (team)" : "{displayName} (team)",
    "Add group or team" : "Lägg till grupp eller team",
    "{size} used" : "{size} använt",
    "Other …" : "Övrigt ...",
    "You can not remove your own read permission." : "Du kan inte ta bort din egen läsbehörighet.",
    "Group folders" : "Gruppmappar",
    "Admin configured folders shared with everyone in a group" : "Admin-konfigurerade mappar som delas av alla i en grupp",
    "Admin configured folders shared with everyone in a group.\n\nFolders can be configured from *Group folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more groups, control their write/sharing permissions and assign a quota for the folder." : "Admin-konfigurerade mappar som delas med alla i en grupp.\n\nMappar kan konfigureras från *Gruppmappar* i admininställningarna.\n\nNär en mapp har skapats kan administratören ge åtkomst till mappen till en eller flera grupper, kontrollera deras skriv/delnings-behörigheter och tilldela en kvot för mappen.",
    "Group folder" : "Gruppmapp",
    "Open group folder" : "Öppna gruppmapp",
    "List of group folders." : "Lista över gruppmappar.",
    "No group folders yet" : "Inga gruppmappar än",
    "Group folders will show up here" : "Gruppmappar kommer att visas här",
    "Group folder admin delegation" : "Administratörsdelegering för gruppmapp",
    "Nextcloud allows you to delegate the administration of group folders to non-admin users." : "Nextcloud tillåter att du delegerar administrationen av gruppmappar till användare som inte är administratörer.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST." : "Ange nedan vilka grupper som tillåts hantera gruppmappar och använda dess API/REST.",
    "They will have access to all group folders." : "De kommer att ha tillgång till alla gruppmappar.",
    "Specify below the groups that will be allowed to manage group folders and use its API/REST only." : "Ange nedan vilka grupper som får hantera gruppmappar och endast använda dess API/REST.",
    "They will only have access to group folders for which they have advanced permissions." : "De kommer bara att ha tillgång till gruppmappar som de har avancerade behörigheter för.",
    "Admin configured folders shared with everyone in a team" : "Admin-konfigurerade mappar som delas av alla i ett team",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder." : "Admin-konfigurerade mappar som delas med alla i ett team.\n\nMappar kan konfigureras från *Teammappar* i admininställningarna.\n\nNär en mapp har skapats kan administratören ge åtkomst till mappen till ett eller flera team, kontrollera deras skriv/delnings-behörigheter och tilldela en kvot för mappen.",
    "Admin configured folders shared with everyone in a team.\n\nFolders can be configured from *Team folders* in the admin settings.\n\nAfter a folder is created, the admin can give access to the folder to one or more teams, control their write/sharing permissions and assign a quota for the folder.\nAs of Hub 10/Nextcloud 31, the admin needs to be a part of the team to be able to assign it a Teamfolder." : "Administratörskonfigurerade mappar delas med alla i ett team.\n\nMappar kan konfigureras från \"Teammappar\" i admininställningarna.\n\nNär en mapp har skapats kan administratören ge åtkomst till en eller flera team, kontrollera deras skriv-/delningsbehörigheter och tilldela en kvot för mappen.\nFrån och med Hub 10/Nextcloud 31 måste administratören vara en del av teamet för att kunna tilldela det en Teammapp."
},
"nplurals=2; plural=(n != 1);");
